<?php

/**
 * XML-RPC check on Flatnuke version - Client
 *
 * This code builds the XML-RPC client that can call a
 * remote server to know (almost) everything about the
 * version it is using, even getting some useful hints
 * on actions to perform.
 *
 * @author Marco Segato <segatom@users.sourceforge.net>
 * @version 20080121
 * @license http://opensource.org/licenses/gpl-license.php GNU General Public License
 */


// include Flatnuke APIs and XML-RPC protocol
include_once("functions.php");
include_once("include/xmlrpc/IXR.php");

// build XML-RPC client
$client = new IXR_Client('http://myurl/fn_chkversion_server.php');

// call the server and tell it which version you're using
if (!$client->query('flatnuke.getFnVersion', get_fn_version())) {
	$addr = getparam("REMOTE_ADDR", PAR_SERVER, SAN_FLAT);
	fnlog("Check Flatnuke updates", $addr."||".get_username()."||An error occurred (".$client->getErrorCode()."): ".$client->getErrorMessage()); //-> DEBUG
	return;
}

$returncode = $client->getResponse();

switch($returncode) {
	case "NULL":
		echo "Error, no version specified by the client";
	break;
	case "UNKNOWN":
		echo "The client is using an unknown version";
	break;
	case "WARNING":
		echo "The client is using an old and *bugged* version";
	break;
	case "OLD":
		echo "The client is using an old version";
	break;
	case "CURRENT":
		echo "The client is using the latest official version";
	break;
	case "DEVEL":
		echo "The client is using a beta version";
	break;
}

?>